Kantonale Verwaltung Zug
Seestrasse 2
Regierungsgebäude am Postplatz
Postfach 156
6301 Zug
Tel. +41 41 728 33 11 oder Privat unter 033 823 24 94
Fax +41 41 / 728 37 01
info@zg.ch

Tel. Das ist Peters Telefonnummer Peter: 076 986 78 25 (Handy) Peter ist auch auf dem Handy (076 986 78 25) erreichbar Call me at +41 41 728 37 01!

Kantonale Verwaltung Zug
Seestrasse 2
Regierungsgebäude am Postplatz
Postfach 156
6301 Zug
Tel. +41 41 728 33 11oder Privat unter 033 823 24 94
Fax +41 41 728 37 01
info@zg.ch

Tel. Das ist Peters Telefonnummer Peter: 076 986 78 25 (Handy) Peter ist auch auf dem Handy (076 986 78 25) erreichbar Call me at +41 41 728 37 01!